@@ -1,8 +1,6 @@
-from decimal import Decimal
 from typing import Any
 
 from django.apps import apps as django_apps
-from django.core.exceptions import ObjectDoesNotExist
 from django.urls.base import reverse
 from edc_dashboard.url_names import url_names
 from edc_model_wrapper import ModelWrapper
@@ -50,7 +48,7 @@ class AppointmentModelWrapper(ModelWrapper):
         """Returns a wrapped persisted or non-persisted
         visit model instance.
         """
-        model_obj = self.object.visit
+        model_obj = self.object.related_visit
         if not model_obj:
             visit_model = django_apps.get_model(self.visit_model_wrapper_cls.model)
             model_obj = visit_model(
@@ -103,10 +101,6 @@ class AppointmentModelWrapper(ModelWrapper):
             .order_by("visit_code_sequence")
             .last()
         )
-        # try:
-        #     timepoint = appointment.timepoint + Decimal("0.1")
-        # except AttributeError:
-        #     timepoint = Decimal("0.1")
         try:
             visit_code_sequence = appointment.visit_code_sequence + 1
         except AttributeError:
